#
# spec file for package kscreenlocker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_pam_vendordir:%global _pam_vendordir %_sysconfdir/pam.d}

%bcond_without released
Name:           kscreenlocker
Version:        5.27.11
Release:        1.3
Summary:        Library and components for secure lock screen architecture
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://projects.kde.org/kscreenlocker
Source:         https://download.kde.org/stable/plasma/%{version}/kscreenlocker-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/kscreenlocker-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
Source3:        kde
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules >= 5.98.0
BuildRequires:  kf5-filesystem
BuildRequires:  pam-devel
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5GlobalAccel)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IdleTime)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Screen)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(LayerShellQt) < 6.0.0
BuildRequires:  cmake(Qt5Quick) >= 5.15.0
BuildRequires:  cmake(Qt5QuickWidgets)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
Requires:       pam-config
Requires(post): /usr/bin/killall
Recommends:     %{name}-lang

%description
Library and components for secure lock screen architecture.

%package -n libKScreenLocker5
Summary:        Library and components for secure lock screen architecture
Group:          System/GUI/KDE

%description -n libKScreenLocker5
Library and components for secure lock screen architecture.

%package devel
Summary:        Library and components for secure lock screen architecture - development files
Group:          Development/Libraries/C and C++
Requires:       libKScreenLocker5 = %{version}
Requires:       cmake(Qt5Core)
Requires:       cmake(Qt5X11Extras)

%description devel
Development files for Library and components for secure lock screen architecture.

%lang_package

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%cmake_kf5 -d build -- -DKDE4_COMMON_PAM_SERVICE=kde -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
%cmake_build

%install
# Ship our own file to not depend on a display manager being installed (boo#1108329)
install -D -m0644 %{SOURCE3} %{buildroot}%{_pam_vendordir}/kde
%kf5_makeinstall -C build

%kf5_find_lang

%pre
# TODO: Add a check for kscreenlocker_greet version, once available.
# Upstream told that that would not be possible, but upstream is unreasonable.
if [ $1 = 2 ]; then
    touch /run/kscreenlocker_restart
fi
exit 0

%post
/sbin/ldconfig
if [ $1 = 2 ] && [ -f /run/kscreenlocker_restart ]; then
    /usr/bin/killall -q -TERM kscreenlocker_greet || :
    rm /run/kscreenlocker_restart
fi
exit 0

%post -n libKScreenLocker5 -p /sbin/ldconfig

%postun -n libKScreenLocker5 -p /sbin/ldconfig

%files lang -f %{name}.lang

%files
%license COPYING*
%{_pam_vendordir}/kde
%{_kf5_applicationsdir}/kcm_screenlocker.desktop
%{_kf5_debugdir}/kscreenlocker.categories
%{_kf5_sharedir}/kconf_update/
%{_kf5_plugindir}/
%{_kf5_notifydir}/
%{_kf5_sharedir}/ksmserver/
%dir %{_kf5_sharedir}/kpackage/
%dir %{_kf5_sharedir}/kpackage/kcms
%{_kf5_sharedir}/kpackage/kcms/kcm_screenlocker
%{_libexecdir}/kscreenlocker_greet

%files -n libKScreenLocker5
%license COPYING*
%{_kf5_libdir}/libKScreenLocker.so.*

%files devel
%license COPYING*
%{_kf5_libdir}/libKScreenLocker.so
%{_kf5_prefix}/include/KScreenLocker/
%{_kf5_libdir}/cmake/ScreenSaverDBusInterface/
%{_kf5_libdir}/cmake/KScreenLocker/
%{_kf5_sharedir}/dbus-1/interfaces/

%changelog
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.11:
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.11
- Changes since 5.27.10:
  * Port to new Gitlab template include format
* Wed Feb 28 2024 Christophe Marin <christophe@krop.fr>
- Build with layer-shell-qt from Plasma5
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- Changes since 5.27.9:
  * Adjust to KWayland moving to Plasma
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- Changes since 5.27.8:
  * greeter: disable qml disk cache (kde#471952)
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- No code changes since 5.27.7
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- No code changes since 5.27.6
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- No code changes since 5.27.5
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- Changes since 5.27.4:
  * greeter: track various properties persistently (kde#456210)
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- No code changes since 5.27.2
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- Changes since 5.27.0:
  * Install logging categories, to make them configurable via KDebugSettings
  * CMake: Clean up whitespace
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- Changes since 5.26.90:
  * Only inhibit screen locker on "ChangeScreenSettings" (kde#464119)
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Too many changes to list here
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- Changes since 5.26.4:
  * Fix KSignalHandler initialization order
  * Fix crash condition where kscreenlocker_greet doesn't start
    handle signals in time On mobile, we frequently spam our power
    buttons, of which each triggers a call from PowerDevil to
    ksldapp (in ksmserver) to lock the screen.
  * Fix wallpaper not loading (leaving the background black)
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- Changes since 5.26.0:
  * Revert "Fix loading image wallpaper plugin config UI in KCM"
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * Install po folder
  * wallpapers/image: allow wallpaper plugin to force enable the apply button (kde#438585)
  * kcm: Only assign the shortcut once it's finished capturing (kde#459322)
  * Set QSurfaceFormat::ResetNotification
  * Add the zooming in global shortcut to the whitelist in kscreenlocker (kde#406164)
  * Properly handle signals using KSignalHandler
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Refresh pam credentials when authenticating (kde#457179)
  * Add FreeBSD Qt6 CI support
  * Reduce KIO dependency to just KIOCore
  * Port away from KIO::AccessManager
  * Set normal logging category default severity
  * Remove unneeded call to KDeclarative::setupEngine
  * Port the last remaining QQC1 usage
  * Utilize kcmutils_generate_desktop_file cmake method
  * Add "busy" property to Authenticator
  * Use KIO::AccessManager to block access to external content
  * Use one .h.config file
  * Remove unusned preprocessor macros/expressions
  * Show all headers in qtc6
  * Use POSITION_INDEPENDENT_CODE for helping to build against qt6
  * greeter: fix undefined wallpaper by initializing wallpaper plugin before lock screen
  * greeter: fix build warning by removing moc
  * Initialise pam response in all converse conditions (kde#455608)
  * Remove duplicate headers between cpp/h
  * Drop call to QApplication::desktop in x11locker
  * Add `repaintNeeded` to fix warning
  * Use cmakedefine01
  * Remove unusned preprocessor macros/expressions
  * Handle fallback packages when checking for screenlocker API version
  * Wait for screenlocker UI to call close
  * Remove old non-compliant Ctrl+Alt+L shortcut that interferes with apps (kde#454397)
  * Add missing QFile include
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  9 2022 Thorsten Kukuk <kukuk@suse.com>
- Use %%_pam_vendordir
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- Changes since 5.25.1:
  * greeter: fix undefined wallpaper by initializing wallpaper plugin before lock screen
  * Initialise pam response in all converse conditions (kde#455608)
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- Changes since 5.25.0:
  * Add `repaintNeeded` to fix warning
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- Changes since 5.24.90:
  * Handle fallback packages when checking for screenlocker API version
  * Wait for screenlocker UI to call close
  * Remove old non-compliant Ctrl+Alt+L shortcut that interferes with apps (kde#454397)
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Disable logind integration for kwin's unit tests
  * Add fallback to the absolute path to kscreenlocker_greet (kde#452817)
  * Guard double authenticate calls
  * Fix two minor Qt6 build regressions
  * Cleanup kcheckpass
  * Plasma 5.25 brings breaking API changes to the lockscreen
  * Port screen geometry change handling away from QDesktopWidget
  * Don't recommend current session
  * Port away from deprecated KDeclarative API
  * kcm: Fix the load of wallpaper kcms (kde#452757)
  * Port away from KWayland::Server
  * Remove uneeded default args for plugin constructors
  * Port away from using KAboutData with KCMs
  * Install KCM in new namespaces
  * De-duplicate json metadata of KPackages
  * Remove explicit QuickSettings init method call
  * Use PACKAGE_PREFIX_DIR before any find_dependency() calls
  * Make the CMake config file work in a Qt6 build as well
  * Adapt build system to also support Qt6
  * Port from KDeclarative::ConfigPropertyMap to KConfigPropertyMap
  * Adapt to Layer Shell Qt API change
  * Add form factors to embedded json metadata
  * Port to KLibexec
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
- Restore compatibility with older kf5-filesystem
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%_libdir/libexec with %%_libexecdir (boo#1174075)
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * Add form factors to embedded json metadata
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * Add config option for lock on start
  * Add GitLab CI
  * Remove unneeded X-Plasma-API from KCM metadata
  * Fix warning
  * Fix sleep and hibernate actions
  * Add .kde-ci.yml
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- Changes since 5.23.0:
  * Fix sleep and hibernate actions
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- No code changes since 5.22.90
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * Add keywords to KScreenLocker to improve search
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Avoid creating windows for placeholder screens. (kde#439096)
  * Simplify multi-screen handling
  * Move DBus logic back into the greeter
  * Use imported targets for X11 libs
  * kcheckpass: Fix incorrect kevent() argument
  * Handle ConvPutAuthAbort as an authentication failure (kde#438099)
  * Make it compile with last ecm
  * Remind people to log out of the VT after they unlock the session (kde#410772)
  * --warning: use non-deprecated API
  * Properly define Q_ENUM()
  * [kcm] Fix icon name in metadata.desktop
  * Use version-less qt DBus macros
  * Show kcm on mobile
  * Remove plasmashell protocol leftovers
  * Fix logind test
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- Changes since 5.22.3:
  * Handle ConvPutAuthAbort as an authentication failure (kde#438099)
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- Changes since 5.22.0:
  * [kcm] Fix icon name in metadata.desktop
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * Show kcm on mobile
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Changes since 5.21.5:
  * Migrate to KDECompilerSettings
  * Ignore file
  * Port Q_FOREACH too
  * Use Q_EMIT here
  * No need to unnecessarily delay KSldApp::lockScreenShown
  * Eventually announce window as locked
  * Port from GetSessionByPid (kde#433364)
  * Put the kscreenlocker in the overlay layer
  * Do not set QT_IM_MODULE=qtvirtualkeyboard on wayland
  * wayland: Ensure that the greeter fills the entire screen
  * Use LayerShellQt to implement on Wayland
  * Add pre-commit hook for clang-format
  * clang-tidy: Force braces around statements
  * Add .git-blame-ignore-revs file
  * Run clang-format
  * Remove KDE_BINDIR definition
  * Raise minimum CMake version to 3.16
  * Fix valgrind warning on startup
  * Use versionless Qt cmake target
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- No code changes since 5.21.3
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- No code changes since 5.21.2
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- No code changes since 5.21.0
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- No code changes since 5.20.90
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Changes since 5.20.5:
  * Add .gitignore file to ignore generated .clang-format
  * Fix catalog name (found by Victor Ryzhykh)
  * Fix view geometry updates when screens added/removed (kde#347934)
  * KCM KScreenLocker highlight non default settings
  * operator+/- is disabled for QFlags in qt6
  * delay quit after successful password
  * Use QuickControls 2 StackView (kde#429290)
  * actually replace wallaper pages
  * Use QuickControls 2 StackView (kde#429290)
  * Lock the screen if necessary when connecting to logind
  * Require C++17
  * Do not explicitly define Exec line for KCM
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * actually replace wallaper pages
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- Changes since 5.20.3:
  * Use QuickControls 2 StackView (kde#429290)
  * actually replace wallaper pages
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- No code changes since 5.20.2
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- No code changes since 5.20.0
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- No code changes since 5.19.90
- Drop unneeded seccomp build requirement
- Kill quietly
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Changes since 5.19.5:
  * Remove explicit ECM_KDE_MODULE_DIR
  * Drop empty X-KDE-PluginInfo-Depends
  * Update logind's SetLockedHint
  * Drop seccomp sandboxing
  * Build settings related code only once
  * Fix the race condition fix
  * enable notification for wallpaper configpropertymaps changes
  * Do not require QuickWidgets that is not needed anymore
  * Fix another race condition
  * Fix race condition
  * Fix translations
  * This is a straightforward port of the kcm to qml.
  * Add logo for the repo
  * Fix minor typo
  * Set componentDisplayName on the action collection
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Drop patches, now upstream:
  * 0001-Disable-the-seccomp-sandbox.patch
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- No code changes since 5.19.4
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- No code changes since 5.19.3
* Fri Jul 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to disable the seccomp sandbox (boo#1174448):
  * 0001-Disable-the-seccomp-sandbox.patch
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- No code changes since 5.19.1
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- No code changes since 5.19.0
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- No code changes since 5.18.90
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * bump to require Qt 5.14
  * Add support for logging categories
  * Take file descriptor only instead of whole KWayland Display
  * Populate Greeter process exit stderr
  * Fix disabeling of autolock timeout
  * globalaccel: allow sleep and hibernate keyboard shortcuts
  * Use K_PLUGIN_CLASS_WITH_JSON
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- No code changes since 5.18.4.1
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- No code changes since 5.18.2
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- No code changes since 5.18.1
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- No code changes since 5.18.0
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- Changes since 5.17.90:
  * [kcm] Handle empty shortcut in property fetch (kde#416397)
  * Load user information once on startup
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * KF5_MIN_VERSION for plasma 5.18 is KF5 5.66.0
  * Fix minor EBN issues and typos
  * Have the wallpaper combo managed by KConfigDialogManager
  * Remove dead code
  * Integrate the lnf and wallpaper settings with the KCM logic
  * Move the shortcut management in the settings object
  * it's already define in ecm now
  * Add KDEClangFormat cmake support
  * Add version
  * Port some deprecated methods
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Rename kscreenlocker pam file to kde (boo#1158966)
- Use %%_distconfdir for saving the PAM service file. No migration
  code for .rpmsave added as the file was never supposed to be
  modified.
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- No code changes since 5.17.0
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Changes since 5.16.5:
  * update to latest kf5 dependency
  * Do not allow the greeter to send the same password multiple times (Fix GPG smart card access)
  * [KCM] Draw full QTabWidget frame (kde#410923)
  * Remove unused includes
  * [KCM] Improve text for "lock after wake" feature
  * Improve the look of the Lock Screen KCM UI
  * Allow the "turn off screen" to be used from the lockscreen
  * Remove unused includes
  * Initialize view with the right size
  * foreach -> for
  * Try getting the X keyboard grab multiple times
  * Fix forward declaration
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- Changes since 5.16.4:
  * Port away from deprecated KWindowSystem API
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- No code changes since 5.16.2
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- No code changes since 5.16.0
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- No code changes since 5.15.90
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
  * Add Meta+L shortcut for "Lock Session"
  * Fix window height of Screen Locking KCM (kde#400355)
  * Remove deprecated method
  * Remove deprecated code
  * Port test app to QQC2
  * Fix test app
  * Fix lock screen focus (kde#395639)
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- No code changes since 5.15.4
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- No code changes since 5.15.3
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- Changes since 5.14.90:
  * [KCM] Use a better icon
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * bump KF5 dependency to required 5.54 as agreed at start of Plasma 5.15 cycle
  * [Greeter] Ignore unwritable configuration files (kde#403255)
  * Fix fallback to built-in ui
  * Disable kcrash in greeter in same way as in KWin
  * Use override instead of Q_DECL_OVERRIDE
  * Remove Qt include prefix
  * Use KDEFrameworkCompilerSettings
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Force software rendering when greeter crashed
  * Fix build with libc++
  * Prevent paste in screen locker (kde#388049)
  * Load QtQuickSettings for software rendering
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- No code changes since 5.14.3
* Tue Nov 13 2018 wbauer@tmo.at
- Remove forced migration to pam_unix in %%post (fix for
  boo#931296), pam_unix2 is not available anymore and pam-config
  does that migration automatically
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Thu Nov  1 2018 wbauer@tmo.at
- Mark /etc/pam.d/kscreenlocker as %%config(noreplace) so that
  modifications don't get lost when installing updates (boo#1114258)
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- No code changes since 5.13.90
* Sat Sep 29 2018 fabian@ritter-vogt.de
- Ship a copy of the xdm PAM file to not depend on a display manager
  being installed (boo#1108329)
- Drop fix-wayland-version-requirement.diff, not needed anymore
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * Fix the plasma-workspace build.
  * Export install location for DBUS interfaces via CMake
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Install our org.kde.screensaver interface definition
  * Prevent paste in screen locker (kde#388049)
  * Load QtQuickSettings for software rendering
  * Force software rendering when greeter crashed
  * Fix build, remove some implicit QString casts
  * Make it compile with strict compile flags
  * Add explicit
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * Prevent paste in screen locker (kde#388049)
  * Load QtQuickSettings for software rendering
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Use the default Plasma wallpaper on the lock screen
  * expose the wallpaper config to the lockscreen
  * Add script to unlock a broken session via ConsoleKit.
  * Update path to fakekcheckpass with latest ECM's bin/ collection
  * Help KSldTest to find its helper binaries with latest ECM's bin/ collection
  * Use explicit
  * Use override
  * Use nullptr
  * Remove module namespace from Qt includes
  * Port away from deprecated KAuthorized::authorizeKAction()
  * Drop ECMPackageConfigHelpers for CMakePackageConfigHelpers
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Use add_test signature where target command gets resolved to binary path
  * Add missing project() in toplevel CMakeLists.txt
  * Bump min cmake version to 3.0, move cmake_minimum_required to top
  * Build test/autotest if BUILD_TESTING is defined
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * None
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * Update size hint of lnf config widget (kde#389483)
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Require Qt 5.9
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * Fix brightness shortcuts in the whitelist
  * Add touchpad shortcuts to the whitelist
  * Fix building autotest on platforms where syscalls are not available
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Remove double margin in KCM UI
  * Load config specified by the LnF theme (kde#384264)
  * Remove unused class SelectImageButton
  * Remove obsolete reviewboardrc file
  * Bump KF5 required version to 5.42
  * Whitelist Switch keyboard layout to shortcuts (kde#378531)
  * port to Package::fileUrl
  * Forbid more syscalls which could modify the filesystem
  * Screenlocker KCM text improvements
  * Change kcm header "Screen Locking Timeouts" to "Configure Screen Locking"
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * Adjust kwinglplatform.cpp for Mesa renderer string changes
  * Fix greeter crashing with software rendering on wayland
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * Workaround crash on lockscreen close
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * seccomp filter: Handle openat as well (kde#384651)
  * Don't dissallow open with write flag syscall on NVIDIA (kde#384005)
  * Tell user to unlock his session only
  * Use Q_DECL_OVERRIDE
  * Fix detection of sys/event.h on FreeBSD < 12
  * include <signal.h> for kill(2)
- Remove patches, now upstream:
  * 0001-Don-t-dissallow-open-with-write-flag-syscall-on-NVID.patch
* Thu Aug 31 2017 fabian@ritter-vogt.de
- Add patch to allow the NVIDIA driver to poke through seccomp and
  thus not crashing (kde#384005):
  * 0001-Don-t-dissallow-open-with-write-flag-syscall-on-NVID.patch
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Wed Jun 14 2017 fabian@ritter-vogt.de
- Fix the kscreenlocker_greet restart in %%post
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * Fixup protocol mismatch between greeter and kcheckpass (kde#380491)
  * Fix detection of sys/event.h on FreeBSD < 12
  * kcheckpass: Add support in for non-Linux platforms via kevent.
- Remove patches, now upstream:
  * 0001-Fixup-protocol-mismatch-between-greeter-and-kcheckpa.patch
* Sun Jun  4 2017 fabian@ritter-vogt.de
- Add upstream patch to fix screenlocker breaking with empty password
  (kde#380491):
  * 0001-Fixup-protocol-mismatch-between-greeter-and-kcheckpa.patch
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * [Greeter] Expose wallpaper QML item as "wallpaper" context property
  * Prevent kcheckpass from becoming an orphan
  * Fix removal of lock window on unmap
  * Terminate kscreenlocker_greet and don't kill it on unlockRequest
  * [autotests] add missing add_test
  * Use seccomp for implementing a sandbox for kscreenlocker_greet
  * Support for long running kcheckpass supporting multiple authentications
  * [greeter] Send the auth result through the server instead return value
  * Add support for emergency message show on Wayland
  * Require PAM by default and provide an option to not require it
  * [ksld] Don't unset greeter connection on destroy unconditionally (kde#377152)
  * [kcheckpass] Drop all outdated/obsoleted checkpass variants
  * [kcheckpass] Drop the conv_legacy support
  * [kcheckpass] Drop the caller command line option
  * [kcheckpass] Drop command line option for username
  * Enable qtvirtualkeyboard QT_IM_MODULE for greeter
  * Add a small test application for kcheckpass
  * [kcheckpass] Drop the ACCEPT_ENV compatibility define
  * [kcheckpass] Drop the throttle handling code
  * [Greeter] Also clear selection clipboard
  * [greeter] Clear clipboard on show (kde#376526)
  * Stop linking X11_Xcursor_LIB in KScreenLocker (kde#376068)
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * fix merge
  * Implement manual focus on click (kde#348789,kde#374289)
- Remove patches, now upstream:
  * 0001-Implement-manual-focus-on-click.patch
* Wed Mar  1 2017 fabian@ritter-vogt.de
- Add upstream patch to fix screenlocker focus on multiscreen systems:
  * 0001-Implement-manual-focus-on-click.patch
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * Merge Plasma/5.8
  * Fix crash in Screen Locker KCM on teardown
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * Fix crash in Screen Locker KCM on teardown
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * None
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * None
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * None
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
- Drop upstreamed Workaround-problems-with-QtQueuedConnection.patch
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Added Workaround-problems-with-QtQueuedConnection.patch
  (kde#361007, kde#361008)
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
- Drop upstreamed 0001-greeter-Dont-quit-when-last-window-closes.patch
* Tue Feb  9 2016 hrvoje.senjan@gmail.com
- Added 0001-greeter-Dont-quit-when-last-window-closes.patch
  (CVE-2016-2312, boo#964548, kde#358125)
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 22 2015 dimstar@opensuse.org
- Update licensetag to GPL-2.0+.
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
